pub enum CreateDataSetError {
AccessDenied(String),
Conflict(String),
InternalFailure(String),
InvalidParameterValue(String),
LimitExceeded(String),
ResourceExists(String),
ResourceNotFound(String),
Throttling(String),
UnsupportedUserEdition(String),
}Expand description
Errors returned by CreateDataSet
Variants
AccessDenied(String)
You don't have access to this item. The provided credentials couldn't be validated. You might not be authorized to carry out the request. Make sure that your account is authorized to use the Amazon QuickSight service, that your policies have the correct permissions, and that you are using the correct access keys.
Conflict(String)
Updating or deleting a resource can cause an inconsistent state.
InternalFailure(String)
An internal failure occurred.
InvalidParameterValue(String)
One or more parameters has a value that isn't valid.
LimitExceeded(String)
A limit is exceeded.
ResourceExists(String)
The resource specified already exists.
ResourceNotFound(String)
One or more resources can't be found.
Throttling(String)
Access is throttled.
UnsupportedUserEdition(String)
This error indicates that you are calling an operation on an Amazon QuickSight subscription where the edition doesn't include support for that operation. Amazon QuickSight currently has Standard Edition and Enterprise Edition. Not every operation and capability is available in every edition.
Implementations
Sourceimpl CreateDataSetError
impl CreateDataSetError
pub fn from_response( res: BufferedHttpResponse, ) -> RusotoError<CreateDataSetError>